@@ -30,7 +30,6 @@
 #include "tool_msgs.h"
 #include "tool_parsecfg.h"
 #include "tool_util.h"
-#include "memdebug.h" /* keep this as LAST include */
 
 /* only acknowledge colon or equals as separators if the option was not
    specified with an initial dash! */
@@ -96,7 +95,7 @@ ParameterError parseconfig(const char *filename, int max_recursive,
     if(curlrc) {
       file = curlx_fopen(curlrc, FOPEN_READTEXT);
       if(!file) {
-        free(curlrc);
+        curlx_free(curlrc);
         return PARAM_READ_ERROR;
       }
       filename = pathalloc = curlrc;
@@ -266,11 +265,11 @@ ParameterError parseconfig(const char *filename, int max_recursive,
     errorf("cannot read config from '%s'", filename);
 
   if(!err && resolved) {
-    *resolved = strdup(filename);
+    *resolved = curlx_strdup(filename);
     if(!*resolved)
       err = PARAM_NO_MEM;
   }
-  free(pathalloc);
+  curlx_free(pathalloc);
   return err;
 }
 
