@@ -27,9 +27,9 @@
 #define CURL_DISABLE_DEPRECATION
 
 /* Now include the curl_setup.h file from libcurl's private libdir (the source
-   version, but that might include "curl_config.h" from the build dir so we
-   need both of them in the include path), so that we get good in-depth
-   knowledge about the system we're building this on */
+   version, but that might include "curl_config.h" from the build directory so
+   we need both of them in the include path), so that we get good in-depth
+   knowledge about the system we are building this on */
 #include "curl_setup.h"
 
 #include <curl/curl.h>
@@ -79,7 +79,7 @@ extern struct curltime tv_test_start; /* for test timing */
 
 extern int coptind;
 extern const char *coptarg;
-int cgetopt(int argc, const char * const argv[], const char *optstring);
+int cgetopt(int argc, const char *const argv[], const char *optstring);
 
 extern int select_wrapper(int nfds, fd_set *rd, fd_set *wr, fd_set *exc,
                           struct timeval *tv);
@@ -427,15 +427,17 @@ void ws_close(CURL *curl);
 
 /* ---------------------------------------------------------------- */
 
-#define exe_select_test(A, B, C, D, E, Y, Z) do {          \
-    int ec;                                                \
-    if(select_wrapper((A), (B), (C), (D), (E)) == -1) {    \
-      ec = SOCKERRNO;                                      \
-      curl_mfprintf(stderr, "%s:%d select() failed, with " \
-                    "errno %d (%s)\n",                     \
-                    (Y), (Z), ec, strerror(ec));           \
-      res = TEST_ERR_SELECT;                               \
-    }                                                      \
+#define exe_select_test(A, B, C, D, E, Y, Z) do {                  \
+    int ec;                                                        \
+    if(select_wrapper((A), (B), (C), (D), (E)) == -1) {            \
+      char ecbuf[STRERROR_LEN];                                    \
+      ec = SOCKERRNO;                                              \
+      curl_mfprintf(stderr, "%s:%d select() failed, with "         \
+                    "errno %d (%s)\n",                             \
+                    (Y), (Z),                                      \
+                    ec, curlx_strerror(ec, ecbuf, sizeof(ecbuf))); \
+      res = TEST_ERR_SELECT;                                       \
+    }                                                              \
   } while(0)
 
 #define res_select_test(A, B, C, D, E) \
@@ -459,7 +461,7 @@ void ws_close(CURL *curl);
 #define TEST_HANG_TIMEOUT 60 * 1000  /* global default */
 
 #define exe_test_timedout(T,Y,Z) do {                                   \
-  timediff_t timediff = curlx_timediff(curlx_now(), tv_test_start);     \
+  timediff_t timediff = curlx_timediff_ms(curlx_now(), tv_test_start);  \
   if(timediff > (T)) {                                                  \
     curl_mfprintf(stderr, "%s:%d ABORTING TEST, since it seems "        \
                   "that it would have run forever (%ld ms > %ld ms)\n", \
