@@ -34,8 +34,6 @@
 
 */
 
-#include "memdebug.h"
-
 #define F_RESUME        (1 << 0)        /* resume/range. */
 #define F_HTTP416       (1 << 1)        /* Server returns http code 416. */
 #define F_FAIL          (1 << 2)        /* Fail on error. */
@@ -44,7 +42,7 @@
 
 struct testparams {
   unsigned int flags; /* ORed flags as above. */
-  CURLcode result; /* Code that should be returned by curl_easy_perform(). */
+  CURLcode res; /* Code that should be returned by curl_easy_perform(). */
 };
 
 static const struct testparams testparams[] = {
@@ -98,27 +96,27 @@ static int onetest(CURL *curl, const char *url, const struct testparams *p,
   test_setopt(curl, CURLOPT_VERBOSE, 1L);
   test_setopt(curl, CURLOPT_RESUME_FROM, (p->flags & F_RESUME) ? 3L : 0L);
   test_setopt(curl, CURLOPT_RANGE, !(p->flags & F_RESUME) ?
-                                   "3-1000000": (char *)NULL);
+                                   "3-1000000" : (char *)NULL);
   test_setopt(curl, CURLOPT_FAILONERROR, (p->flags & F_FAIL) ? 1L : 0L);
   hasbody = 0;
   res = curl_easy_perform(curl);
-  if(res != p->result) {
+  if(res != p->res) {
     curl_mprintf("%zu: bad error code (%d): resume=%s, fail=%s, http416=%s, "
                  "content-range=%s, expected=%d\n", num, res,
-                 (p->flags & F_RESUME) ? "yes": "no",
-                 (p->flags & F_FAIL) ? "yes": "no",
-                 (p->flags & F_HTTP416) ? "yes": "no",
-                 (p->flags & F_CONTENTRANGE) ? "yes": "no",
-                 p->result);
+                 (p->flags & F_RESUME) ? "yes" : "no",
+                 (p->flags & F_FAIL) ? "yes" : "no",
+                 (p->flags & F_HTTP416) ? "yes" : "no",
+                 (p->flags & F_CONTENTRANGE) ? "yes" : "no",
+                 p->res);
     return 1;
   }
   if(hasbody && (p->flags & F_IGNOREBODY)) {
     curl_mprintf("body should be ignored and is not: resume=%s, fail=%s, "
                  "http416=%s, content-range=%s\n",
-                 (p->flags & F_RESUME) ? "yes": "no",
-                 (p->flags & F_FAIL) ? "yes": "no",
-                 (p->flags & F_HTTP416) ? "yes": "no",
-                 (p->flags & F_CONTENTRANGE) ? "yes": "no");
+                 (p->flags & F_RESUME) ? "yes" : "no",
+                 (p->flags & F_FAIL) ? "yes" : "no",
+                 (p->flags & F_HTTP416) ? "yes" : "no",
+                 (p->flags & F_CONTENTRANGE) ? "yes" : "no");
     return 1;
   }
   return 0;
