@@ -23,13 +23,11 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
 #include <curl/multi.h>
 
 static CURLcode test_lib1550(const char *URL)
 {
-  CURLM *handle;
+  CURLM *multi;
   CURLcode res = CURLE_OK;
   static const char * const bl_servers[] =
      {"Microsoft-IIS/6.0", "nginx/0.8.54", NULL};
@@ -37,12 +35,12 @@ static CURLcode test_lib1550(const char *URL)
      {"curl.se:443", "example.com:80", NULL};
 
   global_init(CURL_GLOBAL_ALL);
-  handle = curl_multi_init();
+  multi = curl_multi_init();
   (void)URL;
 
-  curl_multi_setopt(handle, CURLMOPT_PIPELINING_SERVER_BL, bl_servers);
-  curl_multi_setopt(handle, CURLMOPT_PIPELINING_SITE_BL, bl_sites);
-  curl_multi_cleanup(handle);
+  curl_multi_setopt(multi, CURLMOPT_PIPELINING_SERVER_BL, bl_servers);
+  curl_multi_setopt(multi, CURLMOPT_PIPELINING_SITE_BL, bl_sites);
+  curl_multi_cleanup(multi);
   curl_global_cleanup();
   return CURLE_OK;
 }
